mod tracing;

use ::tracing::info;
use eyre::Context;
use figment::{
    providers::{Env, Format, Toml},
    Figment,
};
use serde::Deserialize;

use crate::tracing::set_up_tracing;

#[derive(Deserialize)]
struct Config {
    meaning_of_life: String,
}

#[tokio::main]
async fn main() -> eyre::Result<()> {
    set_up_tracing("rust_tokio_service_template").context("Failed to set up tracing")?;

    let Config { meaning_of_life } = Figment::new()
        .merge(Toml::file("config.toml"))
        .merge(Env::raw())
        .extract()
        .context("Failed to extract config")?;

    info!("The meaning of life is {meaning_of_life}");

    Ok(())
}
